<?php
/*
	Plugin Name: Previsão do Tempo CSites
	Description: Exibe a previsão do tempo com base na sua cidade.
	Version: 1.0
	Author: CSites
	Author URI: https://csites.com.br/
*/

// Adiciona a página de configurações ao menu do WordPress
function previsao_tempo_add_admin_menu() {
    add_options_page(
        'Previsão do Tempo', 
        'Previsão do Tempo', 
        'manage_options', 
        'previsao-tempo', 
        'previsao_tempo_options_page'
    );
}
add_action('admin_menu', 'previsao_tempo_add_admin_menu');

// Registra as configurações
function previsao_tempo_settings_init() {
    register_setting('previsaoTempo', 'previsao_tempo_settings');

    add_settings_section(
        'previsao_tempo_section', 
        __('Dados Gerais', 'wordpress'), 
        null, 
        'previsaoTempo'
    );

    add_settings_field(
        'previsao_tempo_api_key', 
        __('Chave da API', 'wordpress'), 
        'previsao_tempo_api_key_render', 
        'previsaoTempo', 
        'previsao_tempo_section',
        ['label_for' => 'previsao_tempo_api_key', 'description' => 'Faça seu cadastro nesse site https://www.weatherapi.com/']
    );

    add_settings_field(
        'previsao_tempo_cidade', 
        __('Cidade', 'wordpress'), 
        'previsao_tempo_cidade_render', 
        'previsaoTempo', 
        'previsao_tempo_section',
        ['label_for' => 'previsao_tempo_cidade', 'description' => 'Exemplo: Umuarama']
    );

    add_settings_field(
        'previsao_tempo_estado', 
        __('Estado', 'wordpress'), 
        'previsao_tempo_estado_render', 
        'previsaoTempo', 
        'previsao_tempo_section',
        ['label_for' => 'previsao_tempo_estado', 'description' => 'Exemplo: PR']
    );
}
add_action('admin_init', 'previsao_tempo_settings_init');

// Funções para renderizar os campos
function previsao_tempo_api_key_render() {
    $options = get_option('previsao_tempo_settings');
    ?>
    <input type='text' name='previsao_tempo_settings[previsao_tempo_api_key]' id='previsao_tempo_api_key' value='<?php echo $options['previsao_tempo_api_key']; ?>'>
    <p class="description"><?php echo __('Faça seu cadastro no site para obter a chave Key <a target=”_blank” href="https://www.weatherapi.com/">WeatherAPI.com</a>'); ?></p>
    <?php
}

function previsao_tempo_cidade_render() {
    $options = get_option('previsao_tempo_settings');
    ?>
    <input type='text' name='previsao_tempo_settings[previsao_tempo_cidade]' id='previsao_tempo_cidade' value='<?php echo $options['previsao_tempo_cidade']; ?>'>
    <p class="description"><?php echo __('Exemplo: Umuarama'); ?></p>
    <?php
}

function previsao_tempo_estado_render() {
    $options = get_option('previsao_tempo_settings');
    ?>
    <input type='text' name='previsao_tempo_settings[previsao_tempo_estado]' id='previsao_tempo_estado' value='<?php echo $options['previsao_tempo_estado']; ?>'>
    <p class="description"><?php echo __('Exemplo: PR'); ?></p>
    <?php
}

// Função para criar a página de opções
function previsao_tempo_options_page() {
    ?>
    <form action='options.php' method='post'>
        <h2>Configurações da Previsão do Tempo</h2>
        <?php
        settings_fields('previsaoTempo');
        do_settings_sections('previsaoTempo');
        submit_button();
        ?>
    </form>
    <?php
}

// Função para adicionar o shortcode
function previsao_tempo_shortcode($atts) {
    // Obtenha as configurações do usuário
    $options = get_option('previsao_tempo_settings');
    $api_key = $options['previsao_tempo_api_key'];
    $cidade = $options['previsao_tempo_cidade'];
    $estado = $options['previsao_tempo_estado'];
    $pais = 'BR'; // Pode ser ajustado se necessário

    // Construa a URL da API
    $api_url = "https://api.weatherapi.com/v1/forecast.json?key={$api_key}&q={$cidade}-{$estado}&days=1&aqi=no";

    // Faça uma solicitação à API
    $response = wp_remote_get($api_url);

    // Verifique se a solicitação foi bem-sucedida
    if (is_wp_error($response)) {
        return 'Erro ao obter dados da API de previsão do tempo.';
    }

    // Decodifique os dados da resposta
    $data = json_decode(wp_remote_retrieve_body($response));

    // Verifique se os dados são válidos
    if (!$data || !isset($data->forecast->forecastday[0]->day->maxtemp_c) || !isset($data->current->condition->icon)) {
        return 'Dados de previsão do tempo inválidos.';
    }

    // Extraia os dados
    $temp_max = round($data->forecast->forecastday[0]->day->maxtemp_c); // Temperatura máxima em Celsius
    $temp_min = round($data->forecast->forecastday[0]->day->mintemp_c); // Temperatura mínima em Celsius
    $icon = $data->current->condition->icon; // Ícone de condição do tempo

    // Crie a saída HTML
    $output = "
        <div class='previsao-tempo'>
            <img class='icone-tempo' src='{$icon}' alt='Condições do tempo'>
            <span class='temp-max'>{$temp_max}° </span><span class='temp-txt'>máx</span>
            <span class='temp-min'>{$temp_min}°</span> <span class='temp-txt'>mín</span>            
        </div>
    ";

    return $output;
}
add_shortcode('previsao_tempo', 'previsao_tempo_shortcode');

// Função para enfileirar o CSS
function previsao_tempo_enqueue_styles() {
    wp_enqueue_style('previsao-tempo-style', plugins_url('css/previsao-tempo.css', __FILE__));
}
add_action('wp_enqueue_scripts', 'previsao_tempo_enqueue_styles');
